<?php
/**
 * Class SyncApi
 *
 */

class SyncApi {

	private $data = array(); // The plugin output
	private $article_data = array(); // The data of the current post
	private $error = null; // The error string
	private $icms_server_host = ''; // The hostname of the iCMS server (the plugin will download the images and other files from there)
	
	public function __construct() {

		if(empty($_REQUEST['preview'])) {
			// if the post data is not authenticated we give error
			$this->authRequest($_REQUEST['username'], $_REQUEST['password']);
		}
	
		// we set the hostname of the current cms admin server which the request comes from
		if(!empty($_REQUEST['icms_server_host'])) {
			$this->icms_server_host = $_REQUEST['icms_server_host'];
		}

		// to set some important data (such as creating new Authors) the plugin needs administrator privileges
		$this->loginPluginAsAdmin();

		// load the plugin functions
		include_once(ABSPATH.'wp-admin/includes/plugin.php');

		if(!empty($_REQUEST['get_plugin_list'])) { // if we want the list off all plugins

			$this->listPlugins();

		} elseif(!empty($_REQUEST['get_paywall_config'])) { // if we want the LeakyPaywall config
			
			$this->handlePluginLeakyPaywallGetConfig();

		} elseif(!empty($_REQUEST['preview'])) {

			$this->handlePreviewURL(intval($_REQUEST['preview']));

		} elseif(!empty($_REQUEST['revoke'])) { // if we want to revoke a post

			$this->revokeArticle(intval($_REQUEST['id']));

		} else { // if we want to add or modify a post

			// set $this->article_data object from icms article data
			$this->setArticleObjectFromRequest($_REQUEST);

			if(empty($this->error)) { // if no error in setting up the object

				// save article data to post
				$this->saveArticle();

			}
		}
	}

	private function authRequest($username, $password) {
		if (is_null($username)) {
		    header('HTTP/1.0 401 Unauthorized');
		    echo 'Access denied';
		    die();
		}

		$token = get_option('netrix_acess_token');

		if(empty($token)) {
		    header('HTTP/1.0 401 Unauthorized');
		    echo 'Access denied';
		    die();
		}

		if( md5($username.'_BRydr32525_'.$password)!=$token) {
		    header('HTTP/1.0 401 Unauthorized');
		    echo 'Access denied';
		    die();
		}

	}

	private function loginPluginAsAdmin() {

		$admin_user = get_users(array('role' => 'administrator'));
		
		if(!empty($admin_user)) {
			$admin_user = $admin_user[0];
			wp_set_current_user( $admin_user->ID, $admin_user->user_login );
			wp_set_auth_cookie( $admin_user->ID );
			do_action( 'wp_login', $admin_user->user_login, $admin_user );
		}

		$final = [];
			
		foreach(headers_list() as $cookie) {
			if(strstr($cookie, "Set-Cookie: ")) {
				$good = strstr(str_replace("Set-Cookie: ", "", $cookie), "; path=", true);

				if(!in_array($good, $final)) {
					$final[] = $good;
				}
			}
		}

		$this->auth_cookie = implode('; ', $final);
		
		header_remove('Set-Cookie');

		$headers = getallheaders();

		$this->auth_basic = "";

		if(!empty($headers['Authorization'])) {
			$this->auth_basic = $headers['Authorization'];
		}	
	}

	private function listPlugins() {
		$this->PluginList = get_option('active_plugins');
	}
	
	private function handlePluginLeakyPaywallGetConfig() {
		if(is_plugin_active('leaky-paywall/leaky-paywall.php')) {
			try {
				$config = get_leaky_paywall_settings();
				$levels = array();

				foreach($config['levels'] as $key => $level) {
					if(!is_level_deleted($key)) {
						$item = new stdClass;
						$item->id = $key;
						$item->label = $level['label'];
						$levels[] = $item;
					}
				}

				$this->PayWallConfig = $levels;
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
		}
	}

	private function handlePreviewURL($icms_article_id = 0) {
		global $wpdb;
		
		if(empty($icms_article_id)) {
			status_header( 404 );
			nocache_headers();
			include( get_query_template( '404' ) );
			die();
		}

		// Is there a post with this article id?	
		$row = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}netrix_meta WHERE article_id = $icms_article_id");
		
		if(count($row) > 0 && !empty($row[0])) { // If there is a post
		
			$original_article = $row[0];
			
			$preview_url = get_preview_post_link($original_article->post_id)."&t=".time();

			$curlSession = curl_init();
	    	curl_setopt($curlSession, CURLOPT_URL, $preview_url);
			curl_setopt($curlSession, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curlSession, CURLOPT_FOLLOWLOCATION, true);
			curl_setopt($curlSession, CURLOPT_SSL_VERIFYHOST, false);
			curl_setopt($curlSession, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curlSession, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36');

			if(!empty($this->auth_basic)) {
				curl_setopt($curlSession, CURLOPT_HTTPHEADER, array(
					'Authorization: '.$this->auth_basic
				));
			}

			curl_setopt($curlSession, CURLOPT_COOKIE, $this->auth_cookie);
			$post_data = curl_exec($curlSession);

			curl_close($curlSession);

			$post_data = str_replace('<html ','<html style="margin-top: 0px !important;" ', $post_data);

			## remove admin top bar
			$post_data = str_replace('</head>', "<style>#wpadminbar { display: none !important;}</style></head>", $post_data);

			## remove logout links

			preg_match_all('/<a[^>]* href=["\']?([^"\']*)action=logout([^"\']*)(["\'])/', $post_data, $matches);

			foreach($matches[0] as $key => $find) {
				$replace = str_replace($matches[1][$key],'#', $find);
				$replace = str_replace('action=logout','', $replace);
				$replace = str_replace($matches[2][$key],'', $replace);
				$post_data = str_replace($find, $replace, $post_data);
			}
			
			echo($post_data);
			die();
		} else {
			status_header( 404 );
			nocache_headers();
			include( get_query_template( '404' ) );
			die();
		}
	}

	private function revokeArticle($icms_article_id = 0) {
		global $wpdb;
		
		if(empty($icms_article_id)) {
			$this->error = "The original article ID is missing or not applicable!";
			return;
		}

		// Is there a post with this article id?	
		$row = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}netrix_meta WHERE article_id = $icms_article_id");
		
		if(count($row) > 0 && !empty($row[0])) { // If there is a post
		
			$original_article = $row[0];

			// delete from the connection table
			$wpdb->delete($wpdb->prefix."netrix_meta",array('post_id' => $original_article->post_id));

			$post = get_post($original_article->post_id);

			if(!empty($post)){ // If the post is still exists on the wp site (and not deleted in the wp admin)

				wp_delete_post($original_article->post_id, true);

			}
		}

		unset($this->article_data);
		$this->articleRevoked = true;
	}

	private function setArticleObjectFromRequest($request) {
		global $wpdb;

		$request['id'] = intval($request['id']);

		if(empty($request['id'])) {
			$this->error = "The ID of the original article is missing!";
			return;
		}

		if(empty($request['title'])) {
			$this->error = "The Title of the original article is missing!";
			return;
		}

		if(empty($request['date_from'])) { 
			$this->error = "The publications time of the original article is missing!";
			return;
		}

		### Set default datas
		
		$this->article_data = $request;

		unset($this->article_data['id']);
		unset($this->article_data['categories']);
		
		$this->article_data['icms_article_id'] = $request['id'];
		$this->article_data['icms_categories'] = $request['categories'];

		if($this->article_data['active'] == 1) {

			if ( strtotime($this->article_data['date_from']) < strtotime( "tomorrow" ) ) {
				
				$this->article_data['post_status'] = "publish";
				$this->article_data['post_date'] = $this->article_data['date_from'];
				$this->article_data['post_date_gmt'] = get_gmt_from_date($this->article_data['date_from']);
		
			} elseif ( strtotime($this->article_data['date_from']) > strtotime( 'today' ) ) {

				$this->article_data['post_status'] = "future";
				$this->article_data['post_date'] = $this->article_data['date_from'];
				$this->article_data['post_date_gmt'] = get_gmt_from_date($this->article_data['date_from']);

			}

		} else {

			$this->article_data['status'] = "draft";
			$this->article_data['post_date'] = $this->article_data['date_from'];
			$this->article_data['post_date_gmt'] = get_gmt_from_date($this->article_data['date_from']);

		}

		### Insert or update
				
		// Is there a post with this article id?
		$row = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}netrix_meta WHERE article_id = ".$this->article_data['icms_article_id']);
		
		if(count($row) > 0) { // if exists we need to update
		
			$original_article = $row[0];

			$this->article_data['id'] = $original_article->post_id;

			$post = get_post($this->article_data['id']);

			if(empty($post)){ // if there was once but then it was deleted from wp admin, we do like it never were and do an insert

    			$wpdb->delete($wpdb->prefix."netrix_meta",array('post_id' => $this->article_data['id']));
			    $this->article_data['id'] = null;

			}

		} else { // if not we need to insert
			$this->article_data['id'] = null;
		}

		### Categories

		if(empty($this->article_data['icms_categories'])){
			$icms_web_channel = array('Other');
		} elseif(is_array($this->article_data['icms_categories'])) {
			$icms_web_channel = $this->article_data['icms_categories'];
	    } else {
	    	$icms_web_channel = array($this->article_data['icms_categories']);
	    }

	    $categories = get_categories(array(
			'type'                     => 'post',
	        'orderby'                  => 'name',
	        'order'                    => 'ASC',
	        'hide_empty'               => 0,
	        'taxonomy'                 => 'category',
	    ));

	    $this->article_data['categories'] = [];

	    foreach($categories as $category){
	    	if(in_array(html_entity_decode($category->name), $icms_web_channel)) {
				$icms_web_channel = array_diff($icms_web_channel, [html_entity_decode($category->name)]);
				$this->article_data['categories'][] = $category->term_id;
			}
	    }

		if(!empty($icms_web_channel)) {
			$this->article_data['missing_categories'] = $icms_web_channel;
		}


		### Author 

		// multiple author only exist with plugin if in the future there is a need for that

		$this->article_data['author'] = explode(',', $this->article_data['authors']);
		$this->article_data['author'] = $this->article_data['author'][0];

		### Lead image caption and source

		$this->article_data['caption_text'] = stripslashes($this->article_data['image_description']);
		$this->article_data['source_text'] = stripslashes($this->article_data['image_author']);
		$this->article_data['source_text_raw'] = strip_tags($this->article_data['source_text']);

		### Last edit date

		$this->article_data['date_last_edit'] = date('Y-m-d H:i:s');

		if( ! empty( $request['date_last_edit'] ) ) {
			$this->article_data['date_last_edit'] = $request['date_last_edit'];
		}

		$this->article_data['text'] = stripslashes($this->article_data['text']);
	}

	private function saveArticle() {
		global $wpdb;

	    $inserted = false;
	
		// If there is no post id then we crate an inactive one to get a post ID
		if( empty($this->article_data['id']) ) {
			
			$wp_array = array(
				"post_author" => 0,
				"post_date" => "1900-01-01 00:00:00",
				"post_date_gmt" => get_gmt_from_date("1900-01-01 00:00:00"),
				"post_content" => 'none',
	 			"post_title" => $this->article_data['title'],
				"post_excerpt" => '',
 				"post_status" => 'draft',
				"post_type" => 'post',
    		);

			$this->article_data['id'] = wp_insert_post($wp_array);

			$wpdb->insert($wpdb->prefix.'netrix_meta', array( 'article_id' => $this->article_data['icms_article_id'], 'post_id' => $this->article_data['id'] ));

			$inserted = true;
		}

		## Categories

		$this->handleCategories();

		## Tags

		$this->handleTags();

		## Locations

		$this->handleLocations();

		## Author

		$this->handleAuthor($this->article_data['author'], $this->article_data['id']);
		
		## Lead image

		$this->handleLeadImage();

		## Content images

		$this->article_data['text'] = $this->handleImages( $this->article_data['text'] );

		## UPDATE article record

		$old_post_data = get_post($this->article_data['id']);

		wp_update_post(
			array(
				"post_modified" => $this->article_data['date_last_edit'],
				"post_title" => $this->article_data['title'],
				"post_content" => $this->article_data['text'],
				"post_excerpt" => $this->article_data['lead'],
				"comment_status" => ($this->article_data['comments']==1?"open":"closed"),
				"ID" => $this->article_data['id']
			)
		);

		if($inserted || empty(get_option('netrix_update_existing_post_date'))) {

			wp_update_post(
				array(
					"ID" => $this->article_data['id'],
					"post_status" => $this->article_data['post_status'],
					"post_date" => $this->article_data['post_date'],
					"post_date_gmt" => $this->article_data['post_date_gmt']
				)
			);

			// We can only change post status realy if we can modify the post date too
			if($old_post_data->post_status != $this->article_data['post_status']) {
				$post_data = get_post($this->article_data['id']);
				do_action( 'transition_post_status', $this->article_data['post_status'], $old_post_data->post_status, $post_data );
			}

			$post_data = get_post($this->article_data['id']);
			
		}

		if($this->article_data['active'] != 1 || strtotime($this->article_data['date_from'])>time()) {
			// get url for public preview
			flush_rewrite_rules();
		}
		
		## Plugins

		if(!empty($this->article_data['leaky_paywall_visibility_type'])) {
			$this->handlePluginLeakyPaywallSetPost();
		}

		if(!empty($this->article_data['autodescription_title'])) {
			$this->handlePluginAutoDescription();
		}

		if(!empty($this->article_data['acf_fields'])) {
			$this->handlePluginACFFields();
		}

		$this->handlePluginTrinity();
	}

	private function handleCategories() {
		if(!empty($this->article_data['missing_categories'])) {
			foreach ($this->article_data['missing_categories'] as $category) {
				$my_category = array('cat_name' => $category, 'category_parent' => '');

				// Functions to create the category
				require_once( ABSPATH . '/wp-admin/includes/taxonomy.php');

				$category_id = wp_insert_category($my_category);

				$this->article_data['categories'][] = $category_id;
			}
		}

	    wp_set_post_categories($this->article_data['id'], $this->article_data['categories'], false);
		
	}

	private function handleTags() {
	
		if(isset($this->article_data['tags'])) {
			wp_set_post_tags( $this->article_data['id'], $this->article_data['tags'], false ); 
		}

	}

	private function handleLocations() {

		if(isset($this->article_data['locations'])) {
			$taxonomies = get_taxonomies();
			
			if(!empty($taxonomies['location'])) {
			    wp_set_object_terms($this->article_data['id'], explode(',', $this->article_data['locations']), 'location', false);
			}

			if(!empty($taxonomies['locale'])) {
			    wp_set_object_terms($this->article_data['id'], explode(',', $this->article_data['locations']), 'locale', false);
			}
		}

	}

	private function handleAuthor($author, $post_id) {
		
		if(empty($author)){ // If no editor for plugin
			return;
		}

		$user = $this->getUserByUniqField('display_name', $author);

		$this->user = $user;

		if(!empty($user->ID)){ // If author already exists

			$arg = array(
		    	'ID' => $post_id,
		    	'post_author' => $user->ID,
			);

		} elseif(!empty(get_option('netrix_can_create_user'))) { // If author not exists, but we don't have the right to create one, we just use the default one
			
			$arg = array(
				'ID' => $post_id,
				'post_author' => get_option('netrix_default_user'),
			);

		} else { // If author not exists and we have right to create one, we create one

			$password = uniqid();
			$email = uniqid()."@sync.com";
			$names = explode(' ', $author);
			$first_name = $names[0];
			unset($names[0]);
			$last_name = implode(' ', $names);

			$user_data = array(
				'user_login' => $email,
				'user_pass' => $password,
				'user_email' => $email,
				'display_name' => $author,
				'first_name' => $first_name,
				'last_name' => $last_name,
				'role' => 'author',
			);

			$user_id = wp_insert_user($user_data);

			$arg = array(
			    'ID' => $post_id,
			    'post_author' => $user_id,
			);

		}
		
		wp_update_post( $arg );

		$this->handlePluginACFAuthor($author, $post_id);
	}

	private function getUserByUniqField($field,$value) {
		global $wpdb;

        $row = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}users WHERE $field = '$value' ");
        return $row[0];
	}

	private function handleLeadImage() {
		if( ! empty( $this->article_data['image_url'] ) ) { // If there is a lead image

			$source_file_url = $this->icms_server_host . $this->article_data['image_url'];

			// Downolad image from icms server
			if (!$src = $this->downloadFileFromAdminServer($source_file_url)) {
            	$this->error = 'An error occured while syncing images!';
				return;
            }

			// Get wp image file ID
            $attach_id = $this->getImageAttachmentIdByUrl($src);
			$this->article_data['image_wp_url'] = $src; 

			// Set wp image to post
            set_post_thumbnail( $this->article_data['id'], $attach_id );

			$this->handlePluginImageCaption();

            if(!empty($this->article_data['image_description'])) { //  If there is a lead image description

            	wp_update_post(array('ID' => $attach_id, 'post_excerpt' => $this->article_data['caption_text']));
				update_post_meta($attach_id, '_wp_attachment_image_alt', strip_tags($this->article_data['caption_text']));

				// Set lead image photographer if exists in image description
				$this->handleAuthor($this->article_data['source_text_raw'], $attach_id);
        	}
		}	
	}

	private function downloadFileFromAdminServer($source_file_url) {
		global $wpdb;

	    $clear_source_url = explode('?', $source_file_url)[0];

	    // First we check if the image is already exists on the wp server
	    $row = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}netrix_image_meta WHERE source_url='$clear_source_url' ");	

	    if(!empty($row[0])){ // If exists we return the url
	    	return $row[0]->local_url;
	    }

		$upload_dir = wp_upload_dir();

		if(strstr($source_file_url, '?')) {
			$source_file_url .= "&tp=".time();
		} else {
			$source_file_url .= "?tp=".time();
		}

		$curlSession = curl_init();
	    curl_setopt($curlSession, CURLOPT_URL, $source_file_url);
	    curl_setopt($curlSession, CURLOPT_RETURNTRANSFER, true);

    	$image_data = curl_exec($curlSession);
	    curl_close($curlSession);

		if(empty($image_data)) {
			return false;
		}

		$filename = basename( $clear_source_url );

		if ( wp_mkdir_p( $upload_dir['path'] ) ) {
  			$file = $upload_dir['path'] . '/' . $filename;
		} else {
  			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		file_put_contents( $file, $image_data );

		$local_file_url = str_replace($upload_dir['path'],$upload_dir['url'], $file);

		$wp_filetype = wp_check_filetype( $filename, null );

		$attachment = array(
		  'post_mime_type' => $wp_filetype['type'],
		  'post_title' => $filename,
		  'post_content' => '',
		  'post_status' => 'inherit',
		  'guid' => $local_file_url
		);

		$attach_id = wp_insert_attachment( $attachment, $file );


		require_once( ABSPATH . 'wp-admin/includes/image.php' );

		list($width, $height) = getimagesize($file);

		$attach_data = array(
		    'width' => $width,
		    'height' => $height,
		    'file' => ltrim($upload_dir['subdir'].'/'.$filename,'/')
		);

		wp_update_attachment_metadata( $attach_id, $attach_data );

		$wpdb->insert($wpdb->prefix.'netrix_image_meta', array( 'source_url' => $clear_source_url, 'local_url' => $local_file_url, 'attachment_id' => $attach_id ));

		return $local_file_url;
	}

	private function getImageAttachmentIdByUrl($image_url) {
	    global $wpdb;
	    
		$table = $wpdb->prefix . 'netrix_image_meta';
	    $attachment = $wpdb->get_col($wpdb->prepare("SELECT attachment_id FROM $table WHERE local_url = '%s';", $image_url )); 
	    
		return $attachment[0]; 
	}

	private function handleImages($txt) {

		preg_match_all('/< *img[^>]* src *= *["\']?([^"\']*)(["\'])/', $txt, $matches);

        foreach($matches[1] as $key => $img) { // Look up for all image
            if( strpos($img, 'http') !== 0 ) { // If relative url than the image is on the icms server
				
				$src = rtrim($this->icms_server_host,'/').'/'.ltrim($img,'/');
				$src = explode('?', $src);
				$src = $src[0];

                if (!$src = $this->downloadFileFromAdminServer($src)) { // We need to download it
                    $this->error = 'An error occured while syncing images!';
					return;
                }

				$find = $matches[0][$key];
				$replace = str_replace($img, $src, $find);

				// And we need to re-write the HTML tag to serve the downloaded local file
				$txt = str_replace($find, $replace, $txt);
			}
		}

        return $txt;
	}

	private function handlePluginLeakyPaywallSetPost() {
		if(is_plugin_active('leaky-paywall/leaky-paywall.php')) {
			try {
				$visibility = get_post_meta( $this->article_data['id'], '_issuem_leaky_paywall_visibility', true );

				$defaults = array(
					'visibility_type' 		=> 'default',
					'only_visible' 			=> array(),
					'only_always_visible' 	=> array(),
					'always_visible' 		=> array(),
				);

				$visibility = wp_parse_args( $visibility, $defaults );
				$visibility['visibility_type'] = $this->article_data['leaky_paywall_visibility_type'];
				
				switch ( $visibility['visibility_type'] ) {
				
					case 'only':
							$visibility['only_visible'] = array($this->article_data['leaky_paywall_visibility']);
							$visibility['only_always_visible'] = array();
							$visibility['always_visible'] = array();
						break;
				
					case 'onlyalways':
							$visibility['only_visible'] = array();
							$visibility['only_always_visible'] = array($this->article_data['leaky_paywall_visibility']);
							$visibility['always_visible'] = array();
						break;
						
					case 'always':
							$visibility['only_visible'] = array();
							$visibility['only_always_visible'] = array();
							
							if ( in_array( '-1', $this->article_data['leaky_paywall_visibility'] ) )
								$visibility['always_visible'] = array( '-1' );
							else
								$visibility['always_visible'] = array($this->article_data['leaky_paywall_visibility']);
						break;
						
					default:
							$visibility['only_visible'] = array();
							$visibility['only_always_visible'] = array();
							$visibility['always_visible'] = array();
						break;
				
				}
				
				update_post_meta( $this->article_data['id'], '_issuem_leaky_paywall_visibility', $visibility );
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
    	}
	}

	private function handlePluginAutoDescription() {
		if(is_plugin_active('autodescription/autodescription.php')) {
			try {
				update_post_meta($this->article_data['id'],'_genesis_title',$this->article_data['autodescription_title']);
				update_post_meta($this->article_data['id'],'_genesis_description',$this->article_data['autodescription_description']);
				update_post_meta($this->article_data['id'],'_open_graph_title',$this->article_data['autodescription_title']);
				update_post_meta($this->article_data['id'],'_open_graph_description',$this->article_data['autodescription_description']);
				update_post_meta($this->article_data['id'],'_twitter_title',$this->article_data['autodescription_title']);
				update_post_meta($this->article_data['id'],'_twitter_description',$this->article_data['autodescription_description']);

				if(!empty($this->article_data['autodescription_image'])) {
					$src = $this->downloadFileFromAdminServer($this->article_data['autodescription_image']);

					if(!empty($src)) {
						update_post_meta($this->article_data['id'],'_social_image_url', $src);		
					}
				}
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
    	}
	}

	private function handlePluginACFFields() {
		if(is_plugin_active('advanced-custom-fields/acf.php')) {
			try {
				foreach($this->article_data['acf_fields'] as $field => $value) {
					if(strstr($field, 'image_')) {
						$source_file_url = $this->icms_server_host . $value;

						if (!$src = $this->downloadFileFromAdminServer($source_file_url)) {
							$this->error = 'Hiba a képszinkronizáció során!';
						}

						$attach_id = $this->getImageAttachmentIdByUrl($src);

						if(!empty($attach_id)) {
							update_field($field, $attach_id, $this->article_data['id']);
						} else {
							update_field($field, null, $this->article_data['id']);
						}

					} else {
						update_field($field, $value, $this->article_data['id']);
					}
				}
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
    	}
	}

	private function handlePluginACFAuthor($author, $post_id) {
		if(is_plugin_active('advanced-custom-fields/acf.php')) {
			try {
				update_field('custom_byline', $author, $post_id);
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
		}
	}
	
	private function handlePluginImageCaption() {
		if(is_plugin_active('featured-image-caption/featured-image-caption.php')) {
			try {
				$caption = array(
					'caption_text'    => $this->article_data['caption_text'],
					'source_text'    => $this->article_data['source_text'],
					'source_url'    => esc_url($this->article_data['image_wp_url']),
					'new_window'    => (!empty($this->article_data['image_wp_url']) ? true : false),
				);

				update_post_meta($this->article_data['id'], '_'.CCFIC_KEY, $caption);
			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}
        } 
	}

	private function handlePluginTrinity() {
		if(is_plugin_active('trinity-audio/trinity.php')) {
			try {
				require_once( ABSPATH . '/wp-content/plugins/trinity-audio/inc/constants.php');
				require_once( ABSPATH . '/wp-content/plugins/trinity-audio/inc/common.php');

				$nonce = wp_create_nonce('trinity-audio-metabox');

				if(is_callable('trinity_save_post_callback')) {
					$_POST[TRINITY_AUDIO_NONCE_NAME] = $nonce;
					$_POST[TRINITY_AUDIO_ENABLED] = 1;
					$_POST[TRINITY_AUDIO_GENDER_ID] = "";
					$_POST[TRINITY_AUDIO_SOURCE_LANGUAGE] = "";
					$_POST[TRINITY_AUDIO_VOICE_ID] = "";

					trinity_save_post_callback($this->article_data['id'], null, true);
				}

			} catch(Error $er) {
				$this->error = $er->getMessage();
			} catch(Exception $ex) {
				$this->error = $ex->getMessage();
			}

		}
	}
	
	public function export() {
		
		if( ! empty( $this->error ) ) $this->data['error'] = $this->error;
		else {
			$this->data['success'] = true;

			if(!empty($this->article_data['id'])) {
				
				$this->data['frontend_article_id'] = $this->article_data['id'];
				$this->data['url'] = get_permalink($this->article_data['id']);
				
			} elseif(!empty($this->articleRevoked)) {
				$this->data['articleRevoked'] = $this->articleRevoked;
			} elseif(!empty($this->PayWallConfig)) {
				$this->data['paywall_config'] = $this->PayWallConfig;
			} elseif(!empty($this->PluginList)) {
				$this->data['plugin_list'] = $this->PluginList;
			}
		}
	
		return $this->data;
	}

}