<?php defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/*
Plugin Name: ICMS Sync
Plugin URI:  https://netrixlabs.com/downloads/
Description: Sync articles from Netrix ICMS API to WordPress Posts
Version:     2.1.0
Author:      NETRIX
Author URI:  https://netrixlabs.com/
License:     GPL2
License URI: https://netrixlabs.com/
Domain Path: /languages
*/

define('ICMSSyncVersion', '2.1.0');
// create custom plugin settings menu
add_action('admin_menu', 'icms_sync_plugin_create_menu');

function icms_sync_plugin_create_menu() {

    //create new top-level menu
    add_menu_page('Netrix icms sync', 'Netrix icms sync', 'administrator', 'Netrix_icms_sync', 'icms_sync_settings_page' );

    //call register settings function
    add_action( 'admin_init', 'icms_sync_settings' );
}


function icms_sync_settings() {
    //register our settings
    register_setting( 'icms-sync-plugin-settings-group', 'netrix_acess_token' );
    register_setting( 'icms-sync-plugin-settings-group', 'netrix_can_create_user' );
    register_setting( 'icms-sync-plugin-settings-group', 'netrix_update_existing_post_date' );
    register_setting( 'icms-sync-plugin-settings-group', 'netrix_default_user' );
}

function icms_sync_settings_page() {
    global $wpdb;
?>
<div class="wrap">
<h1>Netrix icms sync</h1>

<form method="post" action="options.php">
    <?php settings_fields( 'icms-sync-plugin-settings-group' ); ?>
    <?php do_settings_sections( 'icms-sync-plugin-settings-group' ); ?>
    <table class="form-table">
        <tr valign="top">
            <th scope="row">Netrix Acess Token</th>
            <td><input type="text" name="netrix_acess_token" id="netrix_acess_token" style="width: 300px;" value="<?php echo esc_attr( get_option('netrix_acess_token') ); ?>" /></td>
        </tr>
        <tr>
            <th scope="row">Sync can create user</th>
            <td>
                <select name="netrix_can_create_user" id="netrix_can_create_user" style="width: 300px;">
                    <option value="" <?php echo esc_attr( get_option('netrix_can_create_user') )==""?'selected="selected"':""; ?> />Yes</option>
                    <option value="no" <?php echo esc_attr( get_option('netrix_can_create_user') )=="no"?'selected="selected"':""; ?>>No</option>
                </select>
            </td>
        </tr>
        <tr style="<?php echo esc_attr(get_option('netrix_can_create_user'))!="no"?'display: none;':''; ?>">
            <th scope="row">Default user</th>
            <td>
                <select name="netrix_default_user" id="netrix_default_user" style="width: 300px;">
                    <?php foreach (get_users([ 'role__in' => [ 'author', 'contributor', 'administrator' ] ]) as $user) { ?>
                        <option value="<?php echo $user->data->ID; ?>" <?php echo esc_attr( get_option('netrix_default_user') )==$user->data->ID?'selected="selected"':""; ?>><?php echo $user->data->display_name; ?></option>
                    <?php } ?>
                </select>
            </td>
        </tr>
        <tr>
            <th scope="row">Update existing posts post date</th>
            <td>
                <select name="netrix_update_existing_post_date" id="netrix_update_existing_post_date" style="width: 300px;">
                    <option value="" <?php echo esc_attr( get_option('netrix_update_existing_post_date') )==""?'selected="selected"':""; ?> />Yes</option>
                    <option value="no" <?php echo esc_attr( get_option('netrix_update_existing_post_date') )=="no"?'selected="selected"':""; ?>>No</option>
                </select>
            </td>
        </tr>
    </table>

    <script type="text/javascript">
        jQuery(document).ready(function() {
            jQuery('#netrix_can_create_user').on('change',function(){ 
                if(jQuery(this).val()=="") {
                    jQuery('#netrix_default_user').parents('tr').hide();
                } else {
                    jQuery('#netrix_default_user').parents('tr').show();
                }
            });
        });
    </script>
    
    <?php submit_button(); ?>

</form>
</div>
<?php }

add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'icms_sync_plugin_action_links' );

function icms_sync_plugin_action_links( $links ) {
    $first=array();
    $first[] = '<a href="'. esc_url( get_admin_url(null, 'options-general.php?page=Netrix_icms_sync') ) .'">Settings</a>';
    $first[] = sprintf( '<a href="%s" class="thickbox open-plugin-details-modal" aria-label="%s" data-title="%s">%s</a>',
                    esc_url(
                        network_admin_url(
                            'plugin-install.php?tab=plugin-information&plugin=netrix&TB_iframe=true&width=600&height=550'
                        )
                    ),
                    esc_attr( sprintf( __( 'More information about %s' ), 'ICMS Sync' ) ),
                    esc_attr( 'ICMS Sync' ),
                    __( 'View details' )
                );
    $links=array_merge($first,$links);
    return $links;
}

// https://generatewp.com/plugin-readme/ wp plugin readme

add_action('parse_request', 'netrix_url_handler');

function netrix_url_handler() {
    if(strstr($_SERVER["REQUEST_URI"],'icms_sync')){
	add_action('wp_ajax_nopriv_function','netrix_endpoints_do_json');
	do_action('wp_ajax_nopriv_function');
	die();
    }
}


function netrix_endpoints_do_json() {
    //ini_set('allow_url_fopen', 1);
    //ini_set('display_errors', 1);
    //ini_set('display_startup_errors', 1);
    //error_reporting(E_ALL);
    include("SyncApi.php");
    kses_remove_filters();

    header('Cache-Control: no-cache, private');

    $Api = new SyncApi();
    $data = $Api->export();

    kses_init_filters();
    header( 'Content-Type: application/json' );
    echo json_encode($data);
}

global $netrix_db_version;

$netrix_db_version = '2.0.0'; // last version db is modifyed

function netrix_db_install() {
        global $wpdb;
        global $netrix_db_version;

        $installed_version = get_option( "netrix_db_version" );

        if($installed_version!=$netrix_db_version){

		        $table_name = $wpdb->prefix . 'netrix_meta';
                $table_name2 = $wpdb->prefix . 'netrix_image_meta';

                $charset_collate = $wpdb->get_charset_collate();

                $sql = "CREATE TABLE $table_name (
                        `id` int(11) NOT NULL AUTO_INCREMENT,
                        `article_id` int(11) DEFAULT NULL,
                        `post_id` int(11) DEFAULT NULL,
                        PRIMARY KEY (`id`),
                        KEY `search` (`article_id`,`post_id`)
                        ) $charset_collate";

                $sql2 = "CREATE TABLE $table_name2 (
                        `id` int(11) NOT NULL AUTO_INCREMENT,
                        `source_url` varchar(255) DEFAULT NULL,
                        `local_url` varchar(255) DEFAULT NULL,
                        `attachment_id` int(11) NULL,
                        PRIMARY KEY (`id`)
                        ) $charset_collate";

                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

                dbDelta( $sql );
                dbDelta( $sql2 );

                if($installed_version==false){
                        add_option( "netrix_db_version", $netrix_db_version );
                }else{
                        update_option( "netrix_db_version", $netrix_db_version );
                }
        }
}

function netrix_update_db_check() {
    global $netrix_db_version;
    if ( get_site_option( 'netrix_db_version' ) != $netrix_db_version ) {
        netrix_db_install();
    }
}

add_action( 'plugins_loaded', 'netrix_update_db_check' );
add_filter( 'plugins_api', 'icms_sync_plugin_info', 20, 3);


function icms_sync_plugin_info( $res, $action, $args ){
    // do nothing if this is not about getting plugin information
    if( 'plugin_information' !== $action ) {
        return false;
    }
 
    $plugin_slug = 'netrix'; // we are going to use it in many places in this function
 
    // do nothing if it is not our plugin
    if( $plugin_slug !== $args->slug ) {
        return false;
    }
 
    // trying to get from cache first
    if( false == $remote = get_transient( 'icms_sync_update_' . $plugin_slug ) ) {
 
        // info.json is the file with the actual plugin information on your server
        $remote = wp_remote_get( 'https://netrixlabs.com/icms_sync_info.json', array(
            'timeout' => 10,
            'headers' => array(
                'Accept' => 'application/json'
            ) )
        );
 
        if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty(json_decode($remote['body']) ) ) {
            set_transient( 'icms_sync_update_' . $plugin_slug, $remote, 3600 ); // 1 hours cache
        }
 
    }
 
    if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && !empty(json_decode($remote['body']))) {
        
        $remote = json_decode( $remote['body'] );
        $res = new stdClass();
 
        $res->name = $remote->name;
        $res->slug = $plugin_slug;
        $res->version = $remote->version;
        $res->tested = $remote->tested;
        $res->requires = $remote->requires;
        $res->author = $remote->author;
        $res->download_link = $remote->download_url;
        $res->trunk = $remote->download_url;
        $res->requires_php = $remote->requires_php;
        $res->last_updated = $remote->last_updated;
        $res->sections = array(
            'installation' => $remote->sections->installation,
            'changelog' => $remote->sections->changelog
        );
 
        if( !empty( $remote->sections->screenshots ) ) {
            $res->sections['screenshots'] = $remote->sections->screenshots;
        }
 
        if( !empty( $remote->banners)) {
            $res->banners = array(
                'low' => $remote->banners->low,
                'high' => $remote->banners->high
            );
        }

        return $res;
 
    }
 
    return false;
 
}

add_filter('site_transient_update_plugins', 'icms_sync_push_update' );
 
function icms_sync_push_update( $transient ){
 
    if ( empty($transient->checked ) ) {
            return $transient;
        }
 
    // trying to get from cache first, to disable cache comment 10,20,21,22,24
    if( false == $remote = get_transient( 'icms_sync_upgrade_netrix' ) ) {
 
        // info.json is the file with the actual plugin information on your server
        $remote = wp_remote_get( 'https://netrixlabs.com/icms_sync_info.json', array(
            'timeout' => 10,
            'headers' => array(
                'Accept' => 'application/json'
            ) )
        );
 
        if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && !empty( $remote['body'] ) ) {
            set_transient( 'icms_sync_upgrade_netrix', $remote, 3600 ); // 1 hours cache
        }
 
    }
 
    if( $remote && is_array($remote) && !empty($remote['body']) ) {
 
        $remote = json_decode( $remote['body'] );
 
        // your installed plugin version should be on the line below! You can obtain it dynamically of course 
        if( $remote && version_compare( ICMSSyncVersion , $remote->version, '<' ) && version_compare($remote->requires, get_bloginfo('version'), '<' ) ) {
            $res = new stdClass();
            $res->slug = 'netrix';
            $res->plugin = 'icms-sync/icms-sync.php';
            $res->new_version = $remote->version;
            $res->tested = $remote->tested;
            $res->package = $remote->download_url."?v=".uniqid();
            $transient->response[$res->plugin] = $res;
            //$transient->checked[$res->plugin] = $remote->version;
        }
 
    }
    
    return $transient;
}

add_action( 'upgrader_process_complete', 'icms_sync_after_update', 10, 2 );
 
function icms_sync_after_update( $upgrader_object, $options ) {
    if ( $options['action'] == 'update' && $options['type'] === 'plugin' )  {
        // just clean the cache when new plugin version is installed
        delete_transient( 'icms_sync_upgrade_netrix' );
    }
}

function netrix_endpoints_activate() {
        // ensure our endpoint is added before flushing rewrite rules
        flush_rewrite_rules();
}

register_activation_hook( __FILE__, 'netrix_endpoints_activate' );

function netrix_endpoints_deactivate() {
        // flush rules on deactivate as well so they're not left hanging around uselessly
        flush_rewrite_rules();
}

register_deactivation_hook( __FILE__, 'netrix_endpoints_deactivate' );